@@ -1,5 +1,5 @@
-/* C code produced by gperf version 3.0.1 */
-/* Command-line: gperf --language=C --struct-type --slot-name=name --hash-fn-name=c_hash --lookup-fn-name=c_lookup  */
+/* ANSI-C code produced by gperf version 3.0.1 */
+/* Command-line: gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=c_hash --lookup-fn-name=c_lookup  */
 /* Computed positions: -k'1-2,4,6-9,12,14' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -26,7 +26,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
+#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
 #endif
 
 
@@ -159,9 +159,7 @@ inline
 #endif
 #endif
 static unsigned int
-c_hash (str, len)
-     register const char *str;
-     register unsigned int len;
+c_hash (register const char *str, register unsigned int len)
 {
   static unsigned short asso_values[] =
     {
@@ -236,9 +234,7 @@ c_hash (str, len)
 __inline
 #endif
 struct keyword *
-c_lookup (str, len)
-     register const char *str;
-     register unsigned int len;
+c_lookup (register const char *str, register unsigned int len)
 {
   static struct keyword wordlist[] =
     {
@@ -461,22 +457,16 @@ c_lookup (str, len)
   return 0;
 }
 
-int c_reserved_word(const char *, int);
 int
-c_reserved_word(str, len)
-	const char *str;
-	int len;
+c_reserved_word(const char *str, int len)
 {
 	struct keyword *keyword;
 
 	keyword = c_lookup(str, len);
 	return (keyword && IS_RESERVED_WORD(keyword->token)) ? keyword->token : 0;
 }
-int c_reserved_sharp(const char *, int);
 int
-c_reserved_sharp(str, len)
-	const char *str;
-	int len;
+c_reserved_sharp(const char *str, int len)
 {
 	struct keyword *keyword;
 
@@ -486,11 +476,8 @@ c_reserved_sharp(str, len)
 	keyword = c_lookup(str, len);
 	return (keyword && IS_RESERVED_SHARP(keyword->token)) ? keyword->token : 0;
 }
-int c_reserved_yacc(const char *, int);
 int
-c_reserved_yacc(str, len)
-	const char *str;
-	int len;
+c_reserved_yacc(const char *str, int len)
 {
 	struct keyword *keyword;
 
