@@ -21,6 +21,7 @@
 #define _LEXCOMMON_H
 
 #include "incop.h"
+#include "tab.h"
 
 /*
  * Definition of LEXTEXT, LEXLENG, LEXIN and LEXRESTART.
@@ -57,36 +58,14 @@ static int begin_line;
 static int newline_terminate_string = 0;
 
 /*
- * Convert tabs to spaces.
+ * Variables for converting tabs to spaces.
  */
 static int dest_column;
 static int left_spaces;
 
 #define YY_INPUT(buf, result, max_size) do {				\
-	int n = 0;							\
-	while (n < max_size) {						\
-		int c;							\
-		if (left_spaces > 0) {					\
-			left_spaces--;					\
-			c = ' ';					\
-		} else {						\
-			c = getc(LEXIN);				\
-			if (c == EOF) {					\
-				if (ferror(LEXIN))			\
-					die("read error.");		\
-				break;					\
-			}						\
-			if (c == '\t') {				\
-				left_spaces = tabs - dest_column % tabs;\
-				continue;				\
-			}						\
-		}							\
-		buf[n++] = c;						\
-		dest_column++;						\
-		if (c == '\n')						\
-			dest_column = 0;				\
-	}								\
-	result = n;							\
+	result = read_file_detabing(buf, max_size, LEXIN,		\
+			&dest_column, &left_spaces);			\
 } while (0)
 
 #define LINENO lexcommon_lineno
@@ -156,19 +135,19 @@ static int left_spaces;
  * Output routine.
  */
 extern void echoc(int);
-extern void echos(const char *s);
-extern char *generate_guide(int);
+extern void echos(const char *);
+extern const char *generate_guide(int);
 extern void put_anchor(char *, int, int);
-extern void put_include_anchor(struct data *, char *);
-extern void put_reserved_word(char *);
-extern void put_macro(char *);
-extern void unknown_preprocessing_directive(char *, int);
+extern void put_include_anchor(struct data *, const char *);
+extern void put_reserved_word(const char *);
+extern void put_macro(const char *);
+extern void unknown_preprocessing_directive(const char *, int);
 extern void unexpected_eof(int);
-extern void unknown_yacc_directive(char *, int);
-extern void missing_left(char *, int);
+extern void unknown_yacc_directive(const char *, int);
+extern void missing_left(const char *, int);
 extern void put_char(int);
-extern void put_string(char *);
-extern void put_brace(char *);
+extern void put_string(const char *);
+extern void put_brace(const char *);
 extern void put_begin_of_line(int);
 extern void put_end_of_line(int);
 
