@@ -15,13 +15,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 #ifndef _GPATH_H_
 #define _GPATH_H_
 
-void load_gpath(char *);
-char *path2url(char *);
+void load_gpath(const char *);
+const char *path2fid(const char *);
 void unload_gpath(void);
 
 #endif /* ! _GPATH_H_ */
