@@ -26,15 +26,18 @@
 #include "abs2rel.h"
 #include "char.h"
 #include "checkalloc.h"
+#include "compress.h"
 #include "conf.h"
 #include "date.h"
 #include "dbop.h"
 #include "defined.h"
 #include "die.h"
 #include "env.h"
+#include "fileop.h"
 #include "find.h"
 #include "format.h"
 #include "getdbpath.h"
+#include "gpathop.h"
 #include "gtagsop.h"
 #include "idset.h"
 #include "is_unixy.h"
@@ -44,14 +47,13 @@
 #include "makepath.h"
 #include "path.h"
 #include "pathconvert.h"
-#include "gpathop.h"
+#include "pool.h"
 #include "split.h"
 #include "strbuf.h"
 #include "strhash.h"
 #include "strlimcpy.h"
 #include "strmake.h"
 #include "tab.h"
-#include "tagsort.h"
 #include "test.h"
 #include "token.h"
 #include "usable.h"
