@@ -43,7 +43,6 @@
 
 static int tabs = 8;
 
-#define TABPOS(i)	((i)%tabs == 0)
 /*
  * settabs: set default tab stop
  *
@@ -56,70 +55,6 @@ settabs(int n)
 		return;
 	tabs = n;
 }
-/*
- * detab: convert tabs into spaces and print
- *
- *	i)	op	FILE *
- *	i)	buf	string including tabs
- */
-void
-detab(FILE *op, const char *buf)
-{
-	int src, dst;
-	char c;
-
-	src = dst = 0;
-	while ((c = buf[src++]) != 0) {
-		if (c == '\t') {
-			do {
-				(void)putc(' ', op);
-				dst++;
-			} while (!TABPOS(dst));
-		} else {
-			(void)putc(c, op);
-			dst++;
-		}
-	}
-	(void)putc('\n', op);
-}
-/*
- * entab: convert spaces into tabs
- *
- *	io)	buf	string buffer
- */
-void
-entab(char *buf)
-{
-	int blanks = 0;
-	int pos, src, dst;
-	char c;
-
-	pos = src = dst = 0;
-	while ((c = buf[src++]) != 0) {
-		if (c == ' ') {
-			if (!TABPOS(++pos)) {
-				blanks++;		/* count blanks */
-				continue;
-			}
-			/* don't convert single blank into tab */
-			buf[dst++] = (blanks == 0) ? ' ' : '\t';
-		} else if (c == '\t') {
-			while (!TABPOS(++pos))
-				;
-			buf[dst++] = '\t';
-		} else {
-			++pos;
-			while (blanks--)
-				buf[dst++] = ' ';
-			buf[dst++] = c;
-		}
-		blanks = 0;
-	}
-	if (blanks > 0)
-		while (blanks--)
-			buf[dst++] = ' ';
-	buf[dst] = 0;
-}
 /*
  * Read file converting tabs into spaces.
  *
@@ -133,11 +68,21 @@ entab(char *buf)
  * Dest_saved and spaces_saved are control variables.
  * You must initialize them with 0 when the input file is opened.
  */
+#define PUTSPACES \
+	do {									\
+		int n = (spaces < size) ? spaces : size;			\
+		dest += n;							\
+		size -= n;							\
+		spaces -= n;							\
+		do {								\
+			*p++ = ' ';						\
+		} while (--n);							\
+	} while (0)
 size_t
 read_file_detabing(char *buf, size_t size, FILE *ip, int *dest_saved, int *spaces_saved)
 {
 	char *p;
-	int c, dest, spaces, n;
+	int c, dest, spaces;
 
 	if (size == 0)
 		return 0;
@@ -145,8 +90,8 @@ read_file_detabing(char *buf, size_t size, FILE *ip, int *dest_saved, int *space
 	dest = *dest_saved;
 	spaces = *spaces_saved;
 	if (spaces > 0)
-		goto put_spaces;
-	do {
+		PUTSPACES;
+	while (size > 0) {
 		c = getc(ip);
 		if (c == EOF) {
 			if (ferror(ip))
@@ -155,14 +100,7 @@ read_file_detabing(char *buf, size_t size, FILE *ip, int *dest_saved, int *space
 		}
 		if (c == '\t') {
 			spaces = tabs - dest % tabs;
-put_spaces:
-			n = (spaces < size) ? spaces : size;
-			dest += n;
-			size -= n;
-			spaces -= n;
-			do {
-				*p++ = ' ';
-			} while (--n);
+			PUTSPACES;
 		} else {
 			*p++ = c;
 			dest++;
@@ -170,7 +108,7 @@ put_spaces:
 				dest = 0;
 			size--;
 		}
-	} while (size > 0);
+	}
 	*dest_saved = dest;
 	*spaces_saved = spaces;
 	return p - buf;
